% ijisfmt.cls
% LaTeX2e class file for International Journal of Informatics Society (IJIS)
% Save as ijis.cls
% Please suggest changes to: secretariat@infsoc.org

\typeout{Document Class Option `ijisfmt' -- Ver. July 11, 2007}

% Load standard LaTeX article style
\LoadClass{article}

% Define printed area size, margins, etc.
\topmargin -1.1cm
\headheight 0pt
\headsep 1.0cm
\footskip 0pt
\textheight 24.75cm
\textwidth 18.0cm
\columnsep 0.8cm
\columnseprule 0pt
\evensidemargin -1.04cm
\oddsidemargin -1.04cm
\pagestyle{empty}

% Redefine \tiny to 6pt on 7pt spacing:
\def\tiny{\@setsize\tiny{7pt}\vipt\@vipt\let\@listi\@listI}

% Defining Paper Type (2018.6.20 by T.Yoshihiro)
\def\setpapertype#1{\def\papertype{\underline{\bf{#1}}\par}}

% Define style for title
\def\@titlefntext#1{\vskip 1em \parindent 1em #1}

% Define style for author
\def\DAG{$^\dagger$}
\def\DDAG{$^{\ddagger}$}


\def\maketitle{\par
 \begingroup
 \let\@makefntext\@titlefntext
 \twocolumn[\@maketitle]
 \endgroup
 \let\maketitle\relax
 \let\@maketitle\relax
 \gdef\@title{}
 \gdef\@author{}
}

\def\@maketitle{
  \baselineskip 14 pt%14 pt
  \vfill
  \papertype
  \vskip 1.0em
  \centering
  {\Large\bf \@title}\par
  \vskip 2.0em
  {\normalsize \begin{tabular}[t]{c}
   \large \@author
  \end{tabular}} \par
  \vfill
  \vskip 2.0em
}

% Define style for keywords
\def\keywords#1{{\flushleft \boldmath $Keywords$\/}: \ignorespaces 
{#1}}

\def\abst{{\centering \boldmath $Abstract$} - }

% Define styles for sections/subsections
\def\section{\@startsection {section}{1}{\z@}{2.5ex plus 1ex minus
 0.2ex}{1.7ex plus 0.2ex}{\flushleft \large \bf}}
\def\subsection{\@startsection{subsection}{2}{\z@}{2.25ex plus 1ex
 minus 0.2ex}{1.5ex plus .2ex}{\flushleft \large \bf}}

% Change rubber space between figures/tables and text from 20pt to 10pt
\textfloatsep 10pt plus 2pt minus 4pt

% Initializations
\parindent 0.35cm
\flushbottom

% Define footnote style
\let\footnotes@ve = \footnote
\def\footnote{\inhibitglue\footnotes@ve}


% References

\def\@cite#1#2{#1\if@tempswa, #2\fi}

\def\cite{%
 \@ifnextchar[{\@tempswatrue\@xcite}{\@tempswafalse\@xcite[]}
}

\def\@xcite[#1]#2{%
 \if@filesw\immediate\write\@auxout{\string\citation{#2}}\fi
 [\@cite{\@collapse{#2}}{#1}]%
}%

\def\@stripdollars#1{%
 {% we use latex temps, therefore we group
 \edef\@tempd{#1}%
 \def\@tempa##1##2+@?{\def\@tempb{##1}\def\@tempc{##2}}%
  \expandafter\@tempa\@tempd+@?% tempb is first tok, tempc rest.
  \if$\@tempb%
   \def\@tempb##1${\def\@tempa{##1}}%
   \expandafter\@tempb\@tempc % now temp b is stripped stuff
   \@tempa%
  \else
   \@tempd%
  \fi
 }% end of grouping
}% end of def

\def\@collapse#1{%
 {% grouping to allow use of latex temps
 \sfcode`,=2000\relax
 \dimen0=\the\fontdimen2\textfont0\relax
 \xspaceskip = .6\dimen0 plus.3\dimen0 minus.3\dimen0\relax
 \let\@temp\relax
 \@tempcntb\@MM
 \def\@citea{}%
 \@for \@citeb:=#1\do{%
  \@ifundefined{b@\@citeb}%
   {\@temp\@citea{\bf ?}%
    \@tempcntb\@MM\def\@citea{,}\let\@temp\relax%
    \@warning{Citation `\@citeb ' on page \thepage\space undefined}%
   }% end of \@ifundefined #1 arg
   {\@tempcnta\@tempcntb \advance\@tempcnta\@ne
    \edef\MyTemp{\csname b@\@citeb\endcsname}%
    \def\@tempa{\@temptokena=\bgroup}% toss rest (non#) of footmark
    \if0A{\fi% hack to match brackets in \@collapse def
    \afterassignment\@tempa % non# part of cite goes into temp toks
    % NEXT LINE: curly opens in \@tempa, 0 default if non#
    \@tempcntb=0\MyTemp\relax}%
    \ifnum\@tempcntb=0\relax% non-# cite mark SHOULD NOT OCCUR-LDC
     \@tempcntb=\@MM
     \@citea\@stripdollars{\MyTemp}%
     \let\@temp = \relax
     \def\@citea{,}%
    \else % treating cite mark as #
     \edef\@tempd{\number\@tempcntb}%
     \ifnum\@tempcnta=\@tempcntb%
      \ifx\@temp\relax
       \edef\@temp{\@citea\@tempd}%
      \else%
       \edef\@temp{\hbox{]--[}\@tempd}%
      \fi%
     \else%
      \@temp\@citea\@tempd
      \let\@temp\relax
     \fi
    \def\@citea{], [}%
    \fi%
   }% end of @ifundefined #2 arg
  }% end of do loop
  \@temp % drop in last bit saved
 }% end of grouping to allow use of latex temps
}% end of \@collapse def


\def\thebibliography#1{
 \section*{REFERENCES}
 \list{{\normalsize[\arabic{enumi}]}}
      {\settowidth\labelwidth{[#1]}
       \leftmargin\labelwidth
       \advance\leftmargin\labelsep
       \usecounter{enumi}
       \partopsep 0pt
       \parsep 0pt
       \itemsep 0pt
      }
 \def\newblock{\hskip .11em plus .33em minus .07em}
 \sloppy
 \clubpenalty 4000
 \widowpenalty 4000
 \sfcode`\.=1000\relax
 \normalsize
 }

\def\endthebibliography{\normalsize\endlist}

\newcounter{INFSOCbiography}
\def\INFSOCbiography{\sp@INFSOCbiography}

\long\def\sp@INFSOCbiography[#1]#2#3{%
 \raggedbottom
 \refstepcounter{INFSOCbiography}%% <
 \ifnum\c@INFSOCbiography >\@ne
 \else
  \vspace{21mm}\par
 \fi
  \parindent\z@
   \setbox\@tempboxa\hbox{%
    \begin{minipage}[t]{\columnwidth}
     \footnotesize\baselineskip3.5mm \hbadness 8000\relax
     \leavevmode\rlap{\smash{\unitlength 1mm\begin{picture}(25,33)
      \put(-30,-31){\framebox(25,33){\null}}\end{picture}}}%
     \hangindent30mm\hangafter-11\relax
      {\bfseries #2} \ignorespaces
	#3\end{minipage}%
   }%
    \@tempdima\ht\@tempboxa
    \advance \@tempdima \dp\@tempboxa
    \ifdim\@tempdima<34.5mm %% >
     \vbox to 32mm{%
      \leavevmode\smash{\llap{\lower31.5mm\hbox to 30mm{%
       \resizebox{28mm}{!}{\includegraphics{#1}}%
        \hss}}}%
      \footnotesize\baselineskip3.5mm\hbadness8000\relax
      \hangindent30mm\hangafter-11\relax
      {\bfseries #2} 
        \ignorespaces #3%
      \vss
     }%
    \else
     \leavevmode\smash{\llap{\lower31.5mm\hbox to 30mm{%
      \resizebox{25mm}{!}{\includegraphics{#1}}%
       \hss}}}%
     \footnotesize\baselineskip3.5mm\hbadness8000\relax
     \hangindent30mm\hangafter-11\relax
     {\bfseries #2} 
       \ignorespaces #3 %
    \fi
  \par
 \vspace{10mm}%
}
